# Types schema


Shared type definitions

### Classes

### Mixins

### Slots

### Types

#### Built in

 * **Bool**
 * **NCName**
 * **URIorCURIE**
 * **XSDDate**
 * **XSDDateTime**
 * **XSDTime**
 * **float**
 * **int**
 * **str**
#### Defined

 * [Boolean](Boolean.md)  (**Bool**)  - A binary (true or false) value
 * [Date](Date.md)  (**XSDDateTime**)  - a date (year, month and day) in an idealized calendar
 * [Datetime](Datetime.md)  (**XSDDate**) 
 * [Double](Double.md)  (**float**) 
 * [Float](Float.md)  (**float**) 
 * [Integer](Integer.md)  (**int**) 
 * [Ncname](Ncname.md)  (**NCName**)  - Prefix part of CURIE
 * [String](String.md)  (**str**) 
 * [Time](Time.md)  (**XSDTime**)  - A time object represents a (local) time of day, independent of any particular day
 * [Uri](Uri.md)  (**URIorCURIE**)  - a URI or a CURIE
